@@ -7,8 +7,8 @@
 
 ;; URL: https://codeberg.org/ideasman42/emacs-doc-show-inline
 ;; Keywords: convenience
-;; Package-Version: 20251030.2355
-;; Package-Revision: bd132bceb567
+;; Package-Version: 20251126.1144
+;; Package-Revision: 87993d064d02
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -346,7 +346,7 @@ the point should not be moved by this function."
 
         (cond
          ;; Ensure the comment is not a trailing comment of a previous line.
-         ((not
+         ((null
            (eq
             pos-beg-of-line
             (save-excursion
@@ -363,7 +363,7 @@ the point should not be moved by this function."
          ;; Optionally exclude blank lines between the comment and the function definition.
          ((and
            ;; Checking blank lines?
-           (not (zerop doc-show-inline-exclude-blank-lines))
+           (null (zerop doc-show-inline-exclude-blank-lines))
            (let ((blank-lines 0))
              (save-excursion
                (goto-char pos-end)
@@ -828,12 +828,12 @@ XREF-BACKEND is the back-end used to find this symbol."
 
     (with-current-buffer buf
       (cond
-       ((null (get-buffer-window buf t))
-        (doc-show-inline--log-info "idle timer ignored for buffer %S without a window" buf))
-       ((null (bound-and-true-p doc-show-inline-mode))
+       ((not (bound-and-true-p doc-show-inline-mode))
         (doc-show-inline--log-info
          "idle timer ignored for buffer %S without `doc-show-inline-mode' set"
          buf))
+       ((null (get-buffer-window buf t))
+        (doc-show-inline--log-info "idle timer ignored for buffer %S without a window" buf))
        (t
         (doc-show-inline--log-info "idle timer for buffer %S callback running..." buf)
         ;; In the unlikely event of an error, run the timer again.
